@@ -501,3 +501,29 @@ class TestFolium:
         np.testing.assert_allclose(
             bounds, [[18.948267, -178.123152], [71.351633, 173.304726]]
         )
+
+    def test_control_typecheck(self):
+        m = folium.Map(
+            location=[39.949610, -75.150282], zoom_start=5, zoom_control=False
+        )
+        tiles = TileLayer(
+            tiles="OpenStreetMap",
+            show=False,
+            control=False,
+        )
+        tiles.add_to(m)
+
+        with pytest.raises(TypeError) as excinfo:
+            minimap = folium.Control("MiniMap", tiles, position="downunder")
+            minimap.add_js_link(
+                "minimap_js",
+                "https://cdnjs.cloudflare.com/ajax/libs/leaflet-minimap/3.6.1/Control.MiniMap.min.js",
+            )
+            minimap.add_css_link(
+                "minimap_css",
+                "https://cdnjs.cloudflare.com/ajax/libs/leaflet-minimap/3.6.1/Control.MiniMap.css",
+            )
+            minimap.add_to(m)
+        assert "position must be one of ('bottomright', 'bottomleft'" in str(
+            excinfo.value
+        )
